package com.zaleslaw.worldgame.logic.database;

import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;

import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class ExternalDbOpenHelper extends SQLiteOpenHelper {

	//       
	public static String DB_PATH;
	//    
	public static String DB_NAME;
	public SQLiteDatabase database;
	public final Context context;

	public SQLiteDatabase getDb() {
		return database;
	}

	public ExternalDbOpenHelper(Context context, String databaseName) {
		super(context, databaseName, null, 1);
		this.context = context;
		//       
		String packageName = context.getPackageName();
		//DB_PATH = String.format("/data/data/%s/databases/", packageName);
		DB_PATH = "/data/data/" + packageName + "/databases/";
		//DB_PATH = ("")
		DB_NAME = databaseName;
		openDataBase();
	}

	//  ,    
	public void createDataBase() throws IOException{
		boolean dbExist = checkDataBase();
		if (!dbExist) {
			this.getReadableDatabase();
			try {
				copyDataBase();
			} catch (IOException e) {
				Log.e(this.getClass().toString(), "Copying error");
				throw new Error("Error copying database!");
			}
		} else {
			Log.i(this.getClass().toString(), "Database already exists");
		}
	}

	//    
	private boolean checkDataBase() {
		SQLiteDatabase checkDb = null;
		try {
			String path = DB_PATH + DB_NAME;
			checkDb = SQLiteDatabase.openDatabase(path, null,
					SQLiteDatabase.OPEN_READONLY);
		} catch (SQLException e) {
			Log.e(this.getClass().toString(), "Error while checking db");
		}
		//     ,   
		if (checkDb != null) {
			checkDb.close();
		}
		return checkDb != null;
	}

	//   
	private void copyDataBase() throws IOException {
		//         
		//   assets
		InputStream externalDbStream = context.getAssets().open(DB_NAME);

		//        
		String outFileName = DB_PATH + DB_NAME;

		//         
		OutputStream localDbStream = new FileOutputStream(outFileName);

		//  
		byte[] buffer = new byte[1024];
		int bytesRead;
		while ((bytesRead = externalDbStream.read(buffer)) > 0) {
			localDbStream.write(buffer, 0, bytesRead);
		}
		//    ()   
		localDbStream.close();
		externalDbStream.close();

	}

	public SQLiteDatabase openDataBase() throws SQLException {
		String path = DB_PATH + DB_NAME;
		if (database == null) {
			
			/*try {
				createDataBase();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				Log.e(this.getClass().toString(), "Create error");
			}*/
			database = SQLiteDatabase.openDatabase(path, null,
					SQLiteDatabase.OPEN_READWRITE);
		}
		return database;
	}

	@Override
	public synchronized void close() {
		if (database != null) {
			database.close();
		}
		super.close();
	}
	
	
	 public void selectData(ArrayList<String> list, String TABLE_NAME) {
		 //  
	        Cursor cursor = database.query(TABLE_NAME, new String[] {"name"}, null, null, null, null, "name ASC"); //  Cursor     
	              
	        if (cursor.moveToFirst()) {//     ArrayList   
	            do {
	                list.add(cursor.getString(0)); //      
	            } while (cursor.moveToNext());
	        }
	              
	        if ((cursor != null) && !(cursor.isClosed()))
	            cursor.close();
	    }
	 
	 
	 
	 
	public void exec(String query){// SQL-
		database.execSQL(query);
    }
	@Override
	public void onCreate(SQLiteDatabase db) {
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
	}
}